@@ -371,6 +371,70 @@ QString ScriptingService::callInsertMediaHook(QFile *file,
     return markdownText;
 }
 
+/**
+ * Calls the noteTaggingHook function for all script components
+ * This function is called when tags are added to, removed from or renamed in
+ * notes or the tags of a note should be listed
+ *
+ * @param note
+ * @param action can be "add", "remove", "rename" or "list"
+ * @param tagName tag name to be added, removed or renamed
+ * @param newTagName tag name to be renamed to if action = "rename"
+ * @return QString or QStringList (if action = "list") inside a QVariant
+ */
+QVariant ScriptingService::callNoteTaggingHook(Note note, QString action,
+                                               QString tagName,
+                                               QString newTagName) {
+    QMapIterator<int, ScriptComponent> i(_scriptComponents);
+    NoteApi *noteApi = NoteApi::fromNote(note);
+
+    while (i.hasNext()) {
+        i.next();
+        ScriptComponent scriptComponent = i.value();
+        QVariant result;
+
+        if (methodExistsForObject(
+                scriptComponent.object,
+                "noteTaggingHook(QVariant,QVariant,QVariant,QVariant)")) {
+            QMetaObject::invokeMethod(scriptComponent.object,
+                                      "noteTaggingHook",
+                                      Q_RETURN_ARG(QVariant, result),
+                                      Q_ARG(QVariant, QVariant::fromValue(
+                                              static_cast<QObject*>(noteApi))),
+                                      Q_ARG(QVariant, action),
+                                      Q_ARG(QVariant, tagName),
+                                      Q_ARG(QVariant, newTagName));
+
+            if (!result.isNull()) {
+                return result;
+            }
+        }
+    }
+
+    return QVariant();
+}
+
+/**
+ * Checks if a noteTaggingHook function exists in a script
+ * @return true if a function was found
+ */
+bool ScriptingService::noteTaggingHookExists() {
+    QMapIterator<int, ScriptComponent> i(_scriptComponents);
+
+    while (i.hasNext()) {
+        i.next();
+        ScriptComponent scriptComponent = i.value();
+
+        if (methodExistsForObject(
+                scriptComponent.object,
+                "noteTaggingHook(QVariant,QVariant,QVariant,QVariant)")) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 /**
  * Calls the insertingFromMimeDataHook function for an object
  */
